==> structural-search-233.13135.103-sources.jar: com/intellij/structuralsearch/inspection/InspectionProfileUtil.java <==
// Copyright 2000-2022 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.structuralsearch.inspection;

import com.intellij.codeInspection.InspectionProfile;
import com.intellij.codeInspection.InspectionProfileEntry;
import com.intellij.codeInspection.InspectionsBundle;
import com.intellij.codeInspection.ex.InspectionProfileImpl;
import com.intellij.codeInspection.ex.InspectionProfileModifiableModel;
import com.intellij.codeInspection.ex.InspectionToolWrapper;
import com.intellij.openapi.project.Project;
import com.intellij.profile.codeInspection.ui.SingleInspectionProfilePanel;
import com.intellij.structuralsearch.SSRBundle;
import com.intellij.util.ui.UIUtil;
import org.intellij.lang.regexp.inspection.custom.CustomRegExpInspection;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

import java.awt.*;

/**
 * @author Bas Leijdekkers
 */
public final class InspectionProfileUtil {

  private InspectionProfileUtil() {}

  @NotNull
  public static SSBasedInspection getStructuralSearchInspection(@NotNull InspectionProfile profile) {
    return (SSBasedInspection)getInspection(profile, SSBasedInspection.SHORT_NAME);
  }

  public static CustomRegExpInspection getCustomRegExpInspection(@NotNull InspectionProfile profile) {
    return (CustomRegExpInspection)getInspection(profile, CustomRegExpInspection.SHORT_NAME);
  }

  public static InspectionProfileEntry getInspection(@NotNull InspectionProfile profile, @NonNls String shortName) {
    final InspectionToolWrapper<?, ?> wrapper = profile.getInspectionTool(shortName, (Project)null);
    assert wrapper != null;
    return wrapper.getTool();
  }

  public static InspectionProfileModifiableModel getInspectionProfile(@NotNull Component c) {
    final SingleInspectionProfilePanel panel = UIUtil.uiParents(c, true).filter(SingleInspectionProfilePanel.class).first();
    if (panel == null) return null;
    return panel.getProfile();
  }

  public static String[] getGroup() {
    return new String[] {InspectionsBundle.message("group.names.user.defined"), SSRBundle.message("structural.search.group.name")};
  }

  public static void fireProfileChanged(@NotNull InspectionProfileImpl profile) {
    profile.getProfileManager().fireProfileChanged(profile);
  }
}

==> structural-search-241.14494.241-sources.jar: com/intellij/structuralsearch/inspection/InspectionProfileUtil.java <==
// Copyright 2000-2022 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.structuralsearch.inspection;

import com.intellij.codeInspection.InspectionsBundle;
import com.intellij.codeInspection.ex.InspectionProfileImpl;
import com.intellij.codeInspection.ex.InspectionProfileModifiableModel;
import com.intellij.profile.codeInspection.ui.CustomInspectionActions;
import com.intellij.profile.codeInspection.ui.SingleInspectionProfilePanel;
import com.intellij.structuralsearch.SSRBundle;
import com.intellij.util.ui.UIUtil;
import org.jetbrains.annotations.NotNull;

import java.awt.*;

/**
 * @author Bas Leijdekkers
 */
public final class InspectionProfileUtil {

  private InspectionProfileUtil() {}

  public static InspectionProfileModifiableModel getInspectionProfile(@NotNull Component c) {
    final SingleInspectionProfilePanel panel = UIUtil.uiParents(c, true).filter(SingleInspectionProfilePanel.class).first();
    if (panel == null) return null;
    return panel.getProfile();
  }

  public static String[] getGroup() {
    return new String[] {InspectionsBundle.message("group.names.user.defined"), SSRBundle.message("structural.search.group.name")};
  }

  /**
   * @deprecated Use {@link CustomInspectionActions#fireProfileChanged(InspectionProfileImpl)}.
   */
  @Deprecated
  public static void fireProfileChanged(@NotNull InspectionProfileImpl profile) {
    CustomInspectionActions.fireProfileChanged(profile);
  }
}
